==> haskell-primitive-addr-0.1.0.3-46.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive-addr.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 primitive-addr
version:              0.1.0.3
visibility:           public
id:                   primitive-addr-0.1.0.3-3wbUSYdo0SGJSJOmZo4FKd
key:                  primitive-addr-0.1.0.3-3wbUSYdo0SGJSJOmZo4FKd
license:              BSD-3-Clause
copyright:            2019 Andrew Martin
maintainer:           amartin@layer3com.com
author:               Andrew Martin
homepage:             https://github.com/byteverse/primitive-addr
synopsis:             Addresses to unmanaged memory
description:
    This library provides the `Data.Primitive.Addr` module
    that was a part of the `primitive` library before `primitive-0.7.0.0`.

category:             Data
abi:                  bc206621429a6d0b429223a3bc94ab52
exposed:              True
exposed-modules:      Data.Primitive.Addr
import-dirs:          /usr/lib/ghc-9.6.6/site-local/primitive-addr-0.1.0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/primitive-addr-0.1.0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/primitive-addr-0.1.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-addr
hs-libraries:         HSprimitive-addr-0.1.0.3-3wbUSYdo0SGJSJOmZo4FKd
depends:              base-4.18.2.1 primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ
haddock-interfaces:
    /usr/share/doc/haskell-primitive-addr/html/primitive-addr.haddock

haddock-html:         /usr/share/doc/haskell-primitive-addr/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-primitive-addr-0.1.0.3-47-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive-addr.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 primitive-addr
version:              0.1.0.3
visibility:           public
id:                   primitive-addr-0.1.0.3-66wtQYbwumOEtPVgDW0IXA
key:                  primitive-addr-0.1.0.3-66wtQYbwumOEtPVgDW0IXA
license:              BSD-3-Clause
copyright:            2019 Andrew Martin
maintainer:           amartin@layer3com.com
author:               Andrew Martin
homepage:             https://github.com/byteverse/primitive-addr
synopsis:             Addresses to unmanaged memory
description:
    This library provides the `Data.Primitive.Addr` module
    that was a part of the `primitive` library before `primitive-0.7.0.0`.

category:             Data
abi:                  086f432cc0307041f8212d40be2c466e
exposed:              True
exposed-modules:      Data.Primitive.Addr
import-dirs:          /usr/lib/ghc-9.6.6/site-local/primitive-addr-0.1.0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/primitive-addr-0.1.0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/primitive-addr-0.1.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-addr
hs-libraries:         HSprimitive-addr-0.1.0.3-66wtQYbwumOEtPVgDW0IXA
depends:
    base-4.18.2.1 primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi

haddock-interfaces:
    /usr/share/doc/haskell-primitive-addr/html/primitive-addr.haddock

haddock-html:         /usr/share/doc/haskell-primitive-addr/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
